@@ -1,5 +1,5 @@
-from agiflow.config.environment_vars import EnvironmentVars
-from agiflow.config.constants import API_ENDPOINT, SDK_NAME
+from .environment_vars import EnvironmentVars
+from .constants import API_ENDPOINT, SDK_NAME
 
 
 def is_tracing_enabled() -> bool:
