@@ -1,9 +1,9 @@
-from agiflow.opentelemetry.context.constants import (
+from .constants import (
   ContextKeys,
   PromptSettings,
   AssociationProperties
 )
-from agiflow.opentelemetry.context.context import (
+from .context import (
   set_association_properties,
   set_workflow_name,
   set_prompt_settings_context,
@@ -13,11 +13,11 @@ from agiflow.opentelemetry.context.context import (
   get_association_properties,
   get_prompt_settings
 )
-from agiflow.opentelemetry.context.span_from_context import (
+from .span_from_context import (
   set_workflow_name_from_context,
   set_prompt_attributes_from_context,
 )
-from agiflow.opentelemetry.context.context_propagation import (
+from .context_propagation import (
   get_trace_context_from_carrier,
   get_carrier_from_trace_context,
   extract_association_properties_from_http_headers,
