@@ -1,6 +1,6 @@
 from typing import Optional
 from opentelemetry.context import Context, attach, set_value, get_value
-from agiflow.opentelemetry.context.constants import ContextKeys, PromptSettings, AssociationProperties
+from .constants import ContextKeys, PromptSettings, AssociationProperties
 
 
 def set_association_properties(properties: AssociationProperties) -> None:
