@@ -1,10 +1,10 @@
 from typing import Any, Optional
+from opentelemetry.context import Context
 from agiflow.opentelemetry.convention import SpanAttributes
-from agiflow.opentelemetry.context.context import (
+from .context import (
     get_workflow_name,
     get_prompt_settings,
 )
-from opentelemetry.context import Context
 
 
 def set_workflow_name_from_context(span, context: Optional[Context] = None):
