@@ -1,20 +1,20 @@
-from agiflow.opentelemetry.convention.database_span_attributes import (
+from .database_span_attributes import (
   DatabaseSpanAttributes,
   DatabaseSpanAttributesValidator
 )
-from agiflow.opentelemetry.convention.framework_span_attributes import (
+from .framework_span_attributes import (
   FrameworkSpanAttributes,
   FrameworkSpanAttributesValidator
 )
-from agiflow.opentelemetry.convention.llm_span_attributes import (
+from .llm_span_attributes import (
   LLMSpanAttributes,
   LLMSpanAttributesValidator
 )
-from agiflow.opentelemetry.convention.agiflow_attributes import (
+from .agiflow_attributes import (
   AgiflowSpanAttributes,
   AgiflowSpanAttributesValidator
 )
-from agiflow.opentelemetry.convention.constants import (
+from .constants import (
   Event,
   OpenAIMethods,
   ChromaDBMethods,
