@@ -3,7 +3,7 @@ from __future__ import annotations
 from typing import Optional
 
 from pydantic import Field
-from agiflow.opentelemetry.convention.agiflow_attributes import AgiflowSpanAttributesValidator
+from .agiflow_attributes import AgiflowSpanAttributesValidator
 
 
 class FrameworkSpanAttributes():
@@ -11,6 +11,7 @@ class FrameworkSpanAttributes():
     FRAMEWORK_NODE = 'framework.node'
     FRAMEWORK_EDGE = 'framework.edge'
     FRAMEWORK_FINISHPOINT = 'framework.finishpoint'
+    FRAMEWORK_CONFIG = 'framework.config'
 
 
 class FrameworkSpanAttributesValidator(AgiflowSpanAttributesValidator):
@@ -18,3 +19,4 @@ class FrameworkSpanAttributesValidator(AgiflowSpanAttributesValidator):
     FRAMEWORK_NODE: Optional[str] = Field(None, alias=FrameworkSpanAttributes.FRAMEWORK_NODE)
     FRAMEWORK_EDGE: Optional[str] = Field(None, alias=FrameworkSpanAttributes.FRAMEWORK_EDGE)
     FRAMEWORK_FINISH_POINT: Optional[str] = Field(None, alias=FrameworkSpanAttributes.FRAMEWORK_FINISHPOINT)
+    FRAMEWORK_CONFIG: Optional[str] = Field(None, alias=FrameworkSpanAttributes.FRAMEWORK_CONFIG)
