@@ -3,7 +3,7 @@ from __future__ import annotations
 from typing import Optional
 
 from pydantic import Field
-from agiflow.opentelemetry.convention.agiflow_attributes import AgiflowSpanAttributesValidator
+from .agiflow_attributes import AgiflowSpanAttributesValidator
 
 
 class LLMSpanAttributes():
