@@ -1,4 +1,4 @@
-from agiflow.opentelemetry.instrumentation.anthropic.instrumentation import (
+from .instrumentation import (
   AnthropicInstrumentation,
 )
 
