@@ -18,13 +18,13 @@ from agiflow.opentelemetry.convention.constants import Event, LLMTokenUsageKeys,
 from agiflow.opentelemetry.convention.llm_span_attributes import LLMSpanAttributesValidator
 from agiflow.opentelemetry.instrumentation.constants.anthropic import APIS
 from agiflow.utils import serialise_to_json
-from agiflow.opentelemetry.instrumentation.anthropic.hooks.base import AnthropicSpanCapture
 from agiflow.opentelemetry.convention import (
   SpanAttributes,
   AgiflowServiceTypes,
 )
 from agiflow.opentelemetry.utils import should_send_prompts
 from opentelemetry.trace import StatusCode
+from .base import AnthropicSpanCapture
 
 
 class MessageCreateSpanCapture(AnthropicSpanCapture):
