@@ -22,11 +22,10 @@ from wrapt import wrap_function_wrapper
 from agiflow.opentelemetry.instrumentation.utils import (
   stream_wrapper,
 )
-
-from agiflow.opentelemetry.instrumentation.anthropic.hooks import (
+from agiflow.version import __version__
+from .hooks import (
   MessageCreateSpanCapture,
 )
-from agiflow.version import __version__
 
 
 class AnthropicInstrumentation(BaseInstrumentor):
