@@ -1,4 +1,4 @@
-from agiflow.opentelemetry.instrumentation.chroma.hooks.collection_call import (
+from .collection_call import (
   CollectionCallSpanCapture
 )
 
