@@ -1,4 +1,4 @@
-from agiflow.opentelemetry.instrumentation.cohere.instrumentation import (
+from .instrumentation import (
   CohereInstrumentation,
 )
 
