@@ -1,9 +1,9 @@
-from agiflow.opentelemetry.instrumentation.constants.common import (
+from .common import (
   TIKTOKEN_MODEL_MAPPING,
   AGIFLOW_ADDITIONAL_SPAN_ATTRIBUTES_KEY,
   SERVICE_PROVIDERS
 )
-from agiflow.opentelemetry.instrumentation.constants.openai import OPENAI_COST_TABLE, APIS
+from .openai import OPENAI_COST_TABLE, APIS
 
 
 __all__ = [
