@@ -1,4 +1,4 @@
-from agiflow.opentelemetry.instrumentation.groq.instrumentation import (
+from .instrumentation import (
   GroqInstrumentation,
 )
 
