@@ -24,9 +24,9 @@ from agiflow.opentelemetry.instrumentation.utils import (
   async_method_wrapper,
 )
 
-from agiflow.opentelemetry.instrumentation.langchain.hooks import GenericSpanCapture, ChatSpanCapture
 from agiflow.opentelemetry.instrumentation.utils import patch_module_classes
 from agiflow.version import __version__
+from .hooks import GenericSpanCapture, ChatSpanCapture
 
 
 class LangchainInstrumentation(BaseInstrumentor):
