@@ -18,12 +18,11 @@ from typing import Collection
 
 from opentelemetry.instrumentation.instrumentor import BaseInstrumentor
 from opentelemetry.trace import get_tracer
-
-from agiflow.opentelemetry.instrumentation.langchain_community.hooks import (
-  GenericSpanCapture,
-)
 from agiflow.opentelemetry.instrumentation.utils import patch_module_classes
 from agiflow.version import __version__
+from .hooks import (
+  GenericSpanCapture,
+)
 
 
 class LangchainCommunityInstrumentation(BaseInstrumentor):
