@@ -1,4 +1,4 @@
-from agiflow.opentelemetry.instrumentation.langchain_core.instrumentation import (
+from .instrumentation import (
   LangchainCoreInstrumentation,
 )
 
