@@ -16,13 +16,13 @@ limitations under the License.
 
 from typing import Any, Dict
 from agiflow.utils import serialise_to_json
-from agiflow.opentelemetry.instrumentation.langchain_core.hooks.base import LangchainCoreSpanCapture
 from agiflow.opentelemetry.convention import (
   SpanAttributes,
   AgiflowServiceTypes,
   FrameworkSpanAttributesValidator
 )
 from agiflow.opentelemetry.utils import should_send_prompts
+from .base import LangchainCoreSpanCapture
 
 
 class GenericSpanCapture(LangchainCoreSpanCapture):
