@@ -16,13 +16,13 @@ limitations under the License.
 
 from typing import Any, Dict
 from agiflow.utils import serialise_to_json
-from agiflow.opentelemetry.instrumentation.langchain_core.hooks.base import LangchainCoreSpanCapture
 from agiflow.opentelemetry.convention import (
   SpanAttributes,
   AgiflowServiceTypes,
   FrameworkSpanAttributesValidator
 )
 from agiflow.opentelemetry.utils import should_send_prompts
+from .base import LangchainCoreSpanCapture
 
 
 class RunnableSpanCapture(LangchainCoreSpanCapture):
@@ -35,8 +35,10 @@ class RunnableSpanCapture(LangchainCoreSpanCapture):
         }
 
         if should_send_prompts() is True:
-            inputs = {}
-            inputs = {}
+            inputs = {
+                "args": self.fargs,
+                "kwargs": self.fkwargs,
+            }
             if len(self.fargs) > 0:
                 for arg in self.fargs:
                     if isinstance(arg, dict):
@@ -75,6 +77,9 @@ class RunnableSpanCapture(LangchainCoreSpanCapture):
                                 outputs[field] = item.__class__.__name__
                     if isinstance(value, str):
                         outputs[field] = value
+            else:
+                outputs = result
+
             self.set_span_attribute(SpanAttributes.AGIFLOW_ENTITY_OUTPUT, serialise_to_json(outputs))
             if isinstance(result, str):
                 self.set_span_attribute(SpanAttributes.AGIFLOW_ENTITY_OUTPUT, result)
