@@ -1,4 +1,4 @@
-from agiflow.opentelemetry.instrumentation.langgraph.instrumentation import (
+from .instrumentation import (
   LanggraphInstrumentation,
 )
 
