@@ -1,4 +1,4 @@
-from agiflow.opentelemetry.instrumentation.openai.instrumentation import (
+from .instrumentation import (
   OpenAIInstrumentation,
 )
 
