@@ -21,7 +21,7 @@ from agiflow.opentelemetry.convention import SpanAttributes
 from agiflow.opentelemetry.instrumentation.constants.common import (
     SERVICE_PROVIDERS,
 )
-from agiflow.opentelemetry.instrumentation.openai.hooks.base import OpenAISpanCapture
+from .base import OpenAISpanCapture
 
 
 class OpenAILLMSpanCapture(OpenAISpanCapture):
