@@ -25,7 +25,7 @@ from agiflow.opentelemetry.instrumentation.utils import (
   stream_wrapper,
   async_stream_wrapper,
 )
-from agiflow.opentelemetry.instrumentation.openai.hooks import (
+from .hooks import (
   ImageGenerateSpanCapture,
   ChatCompletionSpanCapture,
   EmbeddingSpanCapture,
