@@ -270,6 +270,8 @@ def stream_wrapper(
                 # NOTE: need to implement span_end with capture_stream_output
                 if callable(span_capture.capture_stream_output):
                     return span_capture.capture_stream_output(result)
+                else:
+                    return result
             else:
                 if callable(span_capture.capture_output):
                     error_handler(lambda: span_capture.capture_output(result))
@@ -323,6 +325,8 @@ def async_stream_wrapper(
                 # NOTE: need to implement span_end with capture_stream_output
                 if callable(span_capture.acapture_stream_output):
                     return span_capture.acapture_stream_output(result)
+                else:
+                    return result
             else:
                 if callable(span_capture.capture_output):
                     error_handler(lambda: span_capture.capture_output(result))
