@@ -30,4 +30,4 @@ class NoSampler(Sampler):
         )
 
     def get_description(self) -> str:
-        return "AlwaysOnSampler"
+        return "NoSampler"
